@@ -108,10 +108,6 @@ func SetNodeGroupDefaults(ng *NodeGroup, meta *ClusterMeta) {
 	if ng.SecurityGroups.WithShared == nil {
 		ng.SecurityGroups.WithShared = Enabled()
 	}
-
-	if ng.AMIFamily == NodeImageFamilyBottlerocket {
-		setBottlerocketNodeGroupDefaults(ng)
-	}
 }
 
 // SetManagedNodeGroupDefaults sets default values for a ManagedNodeGroup
@@ -167,6 +163,9 @@ func setNodeGroupBaseDefaults(ng *NodeGroupBase, meta *ClusterMeta) {
 	if ng.InstanceSelector == nil {
 		ng.InstanceSelector = &InstanceSelector{}
 	}
+	if ng.AMIFamily == NodeImageFamilyBottlerocket {
+		setBottlerocketNodeGroupDefaults(ng)
+	}
 }
 
 func setVolumeDefaults(ng *NodeGroupBase, template *LaunchTemplate) {
@@ -246,18 +245,12 @@ func setDefaultNodeLabels(labels map[string]string, clusterName, nodeGroupName s
 	labels[NodeGroupNameLabel] = nodeGroupName
 }
 
-func setBottlerocketNodeGroupDefaults(ng *NodeGroup) {
+func setBottlerocketNodeGroupDefaults(ng *NodeGroupBase) {
 	// Initialize config object if not present.
 	if ng.Bottlerocket == nil {
 		ng.Bottlerocket = &NodeGroupBottlerocket{}
 	}
 
-	// Default to resolving Bottlerocket images using SSM if not specified by
-	// the user.
-	if ng.AMI == "" {
-		ng.AMI = NodeImageResolverAutoSSM
-	}
-
 	// Use the SSH settings if the user hasn't explicitly configured the Admin
 	// Container. If SSH was enabled, the user will be able to ssh into the
 	// Bottlerocket node via the admin container.
@@ -356,23 +349,3 @@ func SetDefaultGitSettings(c *ClusterConfig) {
 		}
 	}
 }
-
-// SetDefaultGitOpsSettings sets the default values for the gitops repo and operator settings
-func SetDefaultGitOpsSettings(c *ClusterConfig) {
-	if c.GitOps == nil {
-		return
-	}
-
-	if c.GitOps.Flux != nil {
-		fluxCfg := c.GitOps.Flux
-		if fluxCfg.Namespace == "" {
-			fluxCfg.Namespace = "flux-system"
-		}
-
-		if fluxCfg.Path == "" {
-			fluxCfg.Path = "clusters/" + c.Metadata.Name
-		}
-
-		return
-	}
-}
