@@ -3,8 +3,10 @@ package cmdutils
 import (
 	"encoding/csv"
 	"fmt"
+	"reflect"
 	"strings"
 
+	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
@@ -59,6 +61,33 @@ var (
 		"profile",
 		"timeout",
 	}
+
+	commonNGFlagsIncompatibleWithConfigFile = []string{
+		"managed",
+		"spot",
+		"instance-types",
+		"nodes",
+		"nodes-min",
+		"nodes-max",
+		"node-type",
+		"node-volume-size",
+		"node-volume-type",
+		"max-pods-per-node",
+		"node-ami",
+		"node-ami-family",
+		"ssh-access",
+		"ssh-public-key",
+		"enable-ssm",
+		"node-private-networking",
+		"node-security-groups",
+		"node-labels",
+		"node-zones",
+		"asg-access",
+		"external-dns-access",
+		"full-ecr-access",
+		"instance-name",
+		"instance-prefix",
+	}
 )
 
 func newCommonClusterConfigLoader(cmd *Cmd) *commonClusterConfigLoader {
@@ -170,38 +199,18 @@ func NewCreateClusterLoader(cmd *Cmd, ngFilter *filter.NodeGroupFilter, ng *api.
 
 	ngFilter.SetExcludeAll(params.WithoutNodeGroup)
 
-	l.flagsIncompatibleWithConfigFile.Insert(
+	clusterFlagsIncompatibleWithConfigFile := []string{
 		"tags",
 		"zones",
-		"managed",
 		"fargate",
-		"spot",
-		"instance-types",
-		"nodes",
-		"nodes-min",
-		"nodes-max",
-		"node-type",
-		"node-volume-size",
-		"node-volume-type",
-		"max-pods-per-node",
-		"node-ami",
-		"node-ami-family",
-		"ssh-access",
-		"ssh-public-key",
-		"enable-ssm",
-		"node-private-networking",
-		"node-security-groups",
-		"node-labels",
-		"node-zones",
-		"asg-access",
-		"external-dns-access",
-		"full-ecr-access",
 		"vpc-private-subnets",
 		"vpc-public-subnets",
 		"vpc-cidr",
 		"vpc-nat-mode",
 		"vpc-from-kops-cluster",
-	)
+	}
+
+	l.flagsIncompatibleWithConfigFile.Insert(append(clusterFlagsIncompatibleWithConfigFile, commonNGFlagsIncompatibleWithConfigFile...)...)
 
 	l.flagsIncompatibleWithoutConfigFile.Insert("install-vpc-controllers")
 
@@ -354,30 +363,7 @@ func validateDryRunOptions(cmd *cobra.Command, incompatibleFlags []string) error
 func NewCreateNodeGroupLoader(cmd *Cmd, ng *api.NodeGroup, ngFilter *filter.NodeGroupFilter, ngOptions CreateNGOptions, mngOptions CreateManagedNGOptions) ClusterConfigLoader {
 	l := newCommonClusterConfigLoader(cmd)
 
-	l.flagsIncompatibleWithConfigFile.Insert(
-		"managed",
-		"nodes",
-		"nodes-min",
-		"nodes-max",
-		"node-type",
-		"node-volume-size",
-		"node-volume-type",
-		"max-pods-per-node",
-		"node-ami",
-		"node-ami-family",
-		"spot",
-		"instance-types",
-		"ssh-access",
-		"ssh-public-key",
-		"enable-ssm",
-		"node-private-networking",
-		"node-security-groups",
-		"node-labels",
-		"node-zones",
-		"asg-access",
-		"external-dns-access",
-		"full-ecr-access",
-	)
+	l.flagsIncompatibleWithConfigFile.Insert(commonNGFlagsIncompatibleWithConfigFile...)
 
 	validateDryRun := func() error {
 		if !ngOptions.DryRun {
@@ -454,14 +440,6 @@ func makeManagedNodegroup(nodeGroup *api.NodeGroup, options CreateManagedNGOptio
 }
 
 func validateManagedNGFlags(cmd *cobra.Command, managed bool) error {
-	if managed {
-		for _, f := range incompatibleManagedNodesFlags() {
-			if flag := cmd.Flag(f); flag != nil && flag.Changed {
-				return ErrUnsupportedManagedFlag(fmt.Sprintf("--%s", f))
-			}
-		}
-		return nil
-	}
 	flagsValidOnlyWithMNG := []string{"spot", "instance-types"}
 
 	if flagName, found := findChangedFlag(cmd, flagsValidOnlyWithMNG); found {
@@ -761,3 +739,83 @@ func NewDeleteIAMServiceAccountLoader(cmd *Cmd, sa *api.ClusterIAMServiceAccount
 
 	return l
 }
+
+// NewUpdateNodegroupLoader will load config or use flags for 'eksctl update nodegroup'.
+func NewUpdateNodegroupLoader(cmd *Cmd) ClusterConfigLoader {
+	l := newCommonClusterConfigLoader(cmd)
+
+	l.validateWithConfigFile = func() error {
+		length := len(l.ClusterConfig.ManagedNodeGroups)
+		if length < 1 {
+			return ErrMustBeSet("managedNodeGroups field")
+		}
+
+		logger.Info("validating nodegroup %q", l.ClusterConfig.ManagedNodeGroups[0].Name)
+
+		var unsupportedFields []string
+		ng := l.ClusterConfig.ManagedNodeGroups[0]
+		var err error
+		if unsupportedFields, err = validateSupportedConfigFields(*ng.NodeGroupBase, []string{"Name"}, unsupportedFields); err != nil {
+			return err
+		}
+
+		if unsupportedFields, err = validateSupportedConfigFields(*ng, []string{"NodeGroupBase", "UpdateConfig"}, unsupportedFields); err != nil {
+			return err
+		}
+
+		if len(unsupportedFields) > 0 {
+			logger.Warning("unchanged fields: the following fields remain unchanged; they are not supported by `eksctl update nodegroup`: %s", strings.Join(unsupportedFields[:], ", "))
+		}
+		return nil
+	}
+
+	l.validateWithoutConfigFile = func() error {
+		if cmd.ClusterConfigFile == "" {
+			return ErrMustBeSet("--config-file")
+		}
+		return nil
+	}
+	return l
+}
+
+// validateSupportedConfigFields parses a config file's fields, evaluates if non-empty fields are supported,
+// and returns an error if a field is not supported.
+func validateSupportedConfigFields(obj interface{}, supportedFields []string, unsupportedFields []string) ([]string, error) {
+	v := reflect.ValueOf(obj)
+	t := v.Type()
+	for fieldNumber := 0; fieldNumber < v.NumField(); fieldNumber++ {
+		if !emptyConfigField(v.Field(fieldNumber)) {
+			if !contains(supportedFields, t.Field(fieldNumber).Name) {
+				unsupportedFields = append(unsupportedFields, t.Field(fieldNumber).Name)
+			}
+		}
+	}
+	return unsupportedFields, nil
+}
+
+// emptyConfigField parses a field's value according to its value then returns true
+// if it is not empty/zero/nil.
+func emptyConfigField(v reflect.Value) bool {
+	switch v.Kind() {
+	case reflect.Int, reflect.Int8, reflect.Int16, reflect.Int32, reflect.Int64:
+		return v.Int() == 0
+	case reflect.Uint, reflect.Uint8, reflect.Uint16, reflect.Uint32, reflect.Uint64:
+		return v.Uint() == 0
+	case reflect.String:
+		return v.String() == ""
+	case reflect.Ptr, reflect.Slice, reflect.Map, reflect.Interface, reflect.Chan:
+		return v.IsNil()
+	case reflect.Bool:
+		return !v.Bool()
+	}
+	return false
+}
+
+func contains(supportedFields []string, fieldName string) bool {
+	for _, f := range supportedFields {
+		if f == fieldName {
+			return true
+		}
+	}
+	return false
+}
